Counts how many quartets are resolved or unresolved in a given tree,
following Brodal2013;textualQuartet.
Usage
ResolvedQuartets(tree, countTriplets = FALSE)
ResolvedTriplets(tree)
Value
ResolvedQuartets() returns a vector of length two, listing the
number of quartets (or triplets) that are [1] resolved; [2] unresolved
in the specified tree.
Arguments
tree
A tree of class phylo.
countTriplets
Logical; if TRUE, the function will return the number
of triplets instead of the number of quartets.
Functions
ResolvedTriplets(): Convenience function to calculate the number of
resolved/unresolved triplets.
Trees with more than 477 leaves risk encountering integer overflow errors,
as the number of quartets is larger than can be stored in R's signed
32-bit integer representation. If warnings are thrown, check subsequent
calculations for errors.
References
See Also
Other enumeration:
AllQuartets(),
CompareQuartets(),
CompareQuartetsMulti()