cpdt_dist_file: Direct entry points to 'cpdt' functions
Description
Functions to calculate rooted triplet distances between pairs of trees.
Input is not checked for sanity.
Usage
cpdt_dist_file(file1, file2)
Value
The distance between the requested trees.
Arguments
- file1, file2
Paths to files containing a tree or trees in Newick format.
Author
Martin R. Smith, after Ramesh Rajaby
Details
Functions are called from R with functions such as TripletDistance.
References
Jansson2017jcbQuartet